@@ -1,5 +1,4 @@
 import React, {createRef} from 'react'
-import DeleteIcon from '@mui/icons-material/Delete'
 import {
   Box,
   Button,
@@ -8,14 +7,12 @@ import {
   InputAdornment,
   LazyTextField,
   ListsProvidedFilters,
-  ListsSelection,
+  ListsSelection, MaterialIcon,
   Paper,
   ProvTable,
   ProvTableProps,
   Tooltip
 } from 'system/components'
-import RefreshIcon from '@mui/icons-material/Refresh'
-import ClearIcon from '@mui/icons-material/BackspaceRounded'
 import {gettext} from 'system/l10n'
 import {dialog} from 'system/dialog'
 import {api} from 'system/api'
@@ -156,7 +153,7 @@ export class EntityTable extends React.Component<EntityTableProps, EntityListSta
                             () => this.props.onSearchChange && this.props.onSearchChange('')
                           )}
                       >
-                        <ClearIcon />
+                        <MaterialIcon icon={'backspace'} />
                       </IconButton>
                     </InputAdornment>
                   )
@@ -225,7 +222,7 @@ export class EntityTable extends React.Component<EntityTableProps, EntityListSta
                     variant={'outlined'}
                     disabled={this.state.itemsSelected.length === 0}
                   >
-                    <DeleteIcon />
+                    <MaterialIcon icon={'delete'} />
                   </Button>
                 </Tooltip>
               </Box>
@@ -238,7 +235,7 @@ export class EntityTable extends React.Component<EntityTableProps, EntityListSta
                   variant={'outlined'}
                   onClick={() => this.listRef.current?.fetch()}
                 >
-                  <RefreshIcon />
+                  <MaterialIcon icon={'refresh'} />
                 </Button>
               </Box>
             )}
