@@ -8,6 +8,8 @@ import React from 'react'
 import {Box, CircularProgress, MaterialIcon} from 'system/components'
 
 
+export type ImageVariant = 'rounded' | 'square' | 'circular'
+
 export type ImageProps = {
   animationDuration?: number          /** Duration of the fading animation, in milliseconds. */
   aspectRatio?: number                /** Override aspect ratio. */
@@ -25,6 +27,7 @@ export type ImageProps = {
   onLoad?: React.EventHandler<any>    /** Fired when the image finished loading. */
   src: string                         /** Specifies the URL of an image. */
   style?: React.CSSProperties         /** Override the inline-styles of the root element. */
+  variant?: ImageVariant  /** The variant of the displaying image. */
 }
 
 
@@ -42,17 +45,19 @@ type ImagePropsDefaults = {
   disableSpinner: boolean
   disableTransition: boolean
   errorIcon: JSX.Element | null
+  variant: ImageVariant
   loading: JSX.Element
 }
 
 const defaults: ImagePropsDefaults = {
-  animationDuration: 3000,
+  animationDuration: 1000,
   aspectRatio: 1,
   color: '#ffffff',
   disableError: false,
   disableSpinner: false,
   disableTransition: false,
   errorIcon: null,
+  variant: 'square',
   loading: <CircularProgress size={48} />
 }
 
@@ -63,6 +68,22 @@ export class Image extends React.Component<ImageProps, ImageState> {
     imageLoaded: false
   }
 
+  public static borderRadiusForVariant = (
+    variant?: ImageVariant,
+    defaultVariant: ImageVariant = 'square'
+  ): string => {
+    switch (variant) {
+      case 'square':
+        return '1px'
+      case 'rounded':
+        return '.5vmax'
+      case 'circular':
+        return '10000px'
+      default:
+        return defaultVariant
+    }
+  }
+
   private getStyles = (): any => {
     const {
       animationDuration,
@@ -85,20 +106,24 @@ export class Image extends React.Component<ImageProps, ImageState> {
         opacity ${(animationDuration ?? defaults.animationDuration) / 2}ms cubic-bezier(0.4, 0.0, 0.2, 1)`
     }
 
+    const borderRadius: string = Image.borderRadiusForVariant(this.props.variant)
+
     return {
       root: {
         backgroundColor: color,
         paddingTop: `calc(1 / ${aspectRatio} * 100%)`,
         position: 'relative',
+        borderRadius,
         ...style
       },
       image: {
         width: '100%',
-        height: '100%',
+        height: this.props.cover ? '100%' : undefined,
         position: 'absolute',
         objectFit: cover ? 'cover' : 'inherit',
         top: 0,
         left: 0,
+        borderRadius,
         ...imageTransition,
         ...imageStyle
       },
@@ -112,6 +137,7 @@ export class Image extends React.Component<ImageProps, ImageState> {
         alignItems: 'center',
         justifyContent: 'center',
         pointerEvents: 'none',
+        borderRadius,
         ...iconContainerStyle
       }
     }
@@ -168,7 +194,6 @@ export class Image extends React.Component<ImageProps, ImageState> {
         {imageProps.src && (
           <img
             {...imageProps}
-            // ref={this.image}
             style={styles.image}
             onLoad={this.handleLoadImage}
             onError={this.handleImageError}
