@@ -5,6 +5,7 @@ import {
   Button,
   IconButton,
   Image,
+  ImageVariant,
   MaterialIcon,
   Modal
 } from 'system/components'
@@ -31,7 +32,9 @@ export type StoredImageProps = {
   permitUpload?: boolean
   imageHeight?: string
   imageWidth?: string
+  imageSize?: string
   style?: any
+  variant?: ImageVariant
 
   onChange?: (fileId: string | null) => void
 }
@@ -132,18 +135,20 @@ export class StoredImage extends React.Component<StoredImageProps, StoredImageSt
 
   render() {
     const fileId: string | null = this.currentFileId
-    const height: string = this.props.imageHeight ?? '10vmax'
-    const width: string | undefined = this.props.imageWidth
+    const height: string = this.props.imageSize ?? this.props.imageHeight ?? '10vmax'
+    const width: string | undefined = this.props.imageSize ?? this.props.imageWidth
     const emptyUrl: string | null =
       this.props.emptyUrl === null
         ? null
         : this.props.emptyUrl
           ?? (routing.mediaAssetPath('system', this.props.permitUpload ? 'image-upload.svg' : 'image.svg'))
     const style: any = Object.assign({}, this.props.style ?? {})
+    const borderRadius: string = style.borderRadius ?? Image.borderRadiusForVariant(this.props.variant)
     style.height = height
     if (width) {
       style.width = width
     }
+    style.borderRadius = borderRadius
 
     return (
       <React.Fragment>
@@ -178,16 +183,15 @@ export class StoredImage extends React.Component<StoredImageProps, StoredImageSt
                 backgroundColor: 'transparent',
                 padding: undefined,
                 paddingTop: undefined,
-                position: 'absolute'
+                position: 'absolute',
+                borderRadius
               }}
               imageStyle={{
-                width: undefined,
-                height: undefined,
                 position: 'relative',
                 overflow: 'hidden',
                 maxWidth: '100%',
                 maxHeight: '100%',
-                borderRadius: '.5vmax'
+                borderRadius
               }}
               cover={this.props.cover}
             />
